@@ -17,9 +17,9 @@ pub mod snapshot;
 pub mod util;
 
 use dirs::home_dir;
+use std::cell::RefCell;
 use std::fs;
 use std::path::Path;
-use std::time::Instant;
 
 pub use primes::{Calcit, CalcitItems};
 
@@ -31,12 +31,17 @@ pub fn load_core_snapshot() -> Result<snapshot::Snapshot, String> {
   snapshot::load_snapshot_data(core_data)
 }
 
-pub fn run_program(init_fn: &str, params: CalcitItems, program_code: &program::ProgramCodeData) -> Result<(), String> {
-  let started_time = Instant::now();
-
+pub fn run_program(
+  init_fn: &str,
+  params: CalcitItems,
+  program_code: &program::ProgramCodeData,
+) -> Result<Calcit, String> {
   let (init_ns, init_def) = util::string::extract_ns_def(init_fn)?;
+
+  let check_warnings: &RefCell<Vec<String>> = &RefCell::new(vec![]);
+
   // preprocess to init
-  match runner::preprocess::preprocess_ns_def(&init_ns, &init_def, &program_code, &init_def) {
+  match runner::preprocess::preprocess_ns_def(&init_ns, &init_def, &program_code, &init_def, None, check_warnings) {
     Ok(_) => (),
     Err(failure) => {
       println!("\nfailed preprocessing, {}", failure);
@@ -45,17 +50,20 @@ pub fn run_program(init_fn: &str, params: CalcitItems, program_code: &program::P
     }
   }
 
+  let warnings = check_warnings.to_owned().into_inner();
+  if warnings.len() > 0 {
+    for message in &warnings {
+      println!("{}", message);
+    }
+    return Err(format!("Found {} warnings, runner blocked", warnings.len()));
+  }
   match program::lookup_evaled_def(&init_ns, &init_def) {
     None => Err(format!("entry not initialized: {}/{}", init_ns, init_def)),
     Some(entry) => match entry {
       Calcit::Fn(_, f_ns, _, def_scope, args, body) => {
         let result = runner::run_fn(&params, &def_scope, &args, &body, &f_ns, &program_code);
         match result {
-          Ok(v) => {
-            let duration = Instant::now().duration_since(started_time);
-            println!("took {}ms: {}", duration.as_micros() as f64 / 1000.0, v);
-            Ok(())
-          }
+          Ok(v) => Ok(v),
           Err(failure) => {
             println!("\nfailed, {}", failure);
             call_stack::display_stack(&failure)?;
